#ifndef _BSS_2D_CODE_READER_H_
#define _BSS_2D_CODE_READER_H_


/*
// Import/Export support
*/

#if defined(_MSC_VER) && defined(_BSS_2D_DLL)
#if defined(_BSS_2D_EXPORTS)
#define BSS_DLL __declspec(dllexport)
#else
#define BSS_DLL __declspec(dllimport)
#endif
#else
#define BSS_DLL
#endif

#ifdef __cplusplus
extern "C" {
#endif


/*
// Definitions of return codes 
*/

#define BSS_2D_OK               (0)
#define BSS_2D_NOTFOUND         (1)
#define BSS_2D_INVALIDARGS      (2)
#define BSS_2D_OUTOFMEMORY      (3)
#define BSS_2D_BADSYMBOL        (4)


/* 
// Structure for general barcode information
*/
typedef struct BSS_2DCodeInfo_Struct
{
    int                 nCenterPosX;           /* Center (X) barcode position on the image    */
    int                 nCenterPosY;           /* Center (Y) barcode position on the image    */
    int                 nDataLength;           /* Length of barcode's data (in bytes)         */
    char*               pchData;               /* Pointer to barcode's data                   */
} bss2DCodeInfo;


/* 
// Read 2DCode barcode symbol on the image
*/
BSS_DLL int BSS_Read2DCode
(
    const unsigned char* pImageData,           /* Pointer to image data                       */
    int                  nImageWidth,          /* The image width                             */
    int                  nImageHeight,         /* The image height                            */
    int                  nImageRowDist,        /* Distance between image's rows (in bytes)    */
    int                  nTryReadMultiple,     /* Try to read multiple barcodes on the image  */
    bss2DCodeInfo**      pp2DCodeInfo,         /* Pointer to array with barcodes' information */
    int*                 pn2DCodeInfoCount     /* Pointer to number of recognized symbol(s)   */
);

/* 
// Release allocated resources 
*/
BSS_DLL int BSS_Release2DCodeResults
(
    bss2DCodeInfo*       p2DCodeInfo,         /* Pointer to array with barcodes' information */
    int                  n2DCodeInfoCount     /* Number of items in the array                */
);

#ifdef __cplusplus
}       /* extern "C" */
#endif

#endif /* _BSS_2D_CODE_READER_H_ */
